@@ -45,12 +45,15 @@ type Config struct {
 	Browser       string
 	RenderShadows bool
 	RenderImages  bool
+	RenderSplash  bool
+	RenderBanner  bool
 
 	Systems []SystemConfig
 
 	Theme struct {
 		Header struct {
 			Selector ThemeItemConfig
+			Spinner ThemeItemConfig
 		}
 
 		DialogBox struct {
@@ -192,6 +195,8 @@ func SetDefaults(cacheDir string) {
 
 	viper.SetDefault("RenderShadows", "true")
 	viper.SetDefault("RenderImages", "true")
+	viper.SetDefault("RenderSplash", "true")
+	viper.SetDefault("RenderBanner", "true")
 
 	// --- Header ---
 	// Header Selector
@@ -209,6 +214,10 @@ func SetDefaults(cacheDir string) {
 	viper.SetDefault("Theme.Header.Selector.Foreground",
 		lipgloss.AdaptiveColor{Light: "#6ca1d0", Dark: "#6ca1d0"})
 
+	// Header Spinner
+	viper.SetDefault("Theme.Header.Spinner",
+		lipgloss.AdaptiveColor{Light: "#FF5FAF", Dark: "#FF5FAF"})
+
 	// --- DialogBox ---
 	// DialogBox Window:Focused
 	viper.SetDefault("Theme.DialogBox.Window.Focused.Margin",
